clc
%format shorteng
format long


% %%%%%%%%%%%%     INPUT    %%%%%%%%%%%% %


    % Concentration when loading [%] %
    Methane = 88.5; 
    Ethane = 8;
    Propane = 2;
    isoButane = 0.25;
    nButane = 0.25;
    Nitrogen = 1.0;

    % Boil-off rate [Volume fraction per day]
    BOR = 0.0012; 
    
    % Number of days at sea
    D = 60;
    %Interval for calculation of BOG
    int = 1; % Should always be equal 1 when uding the model.
    %Tank Volume
    V = 144000; %m3 %Check amount much after loading
    %Loading hours
    t = 15;
    %Amount [kg/hour] flashing off when loading
    m_flash = 24000; %Set as zero if no flashing
    %Density loaded LNG
    Rho_LNG = 465; % [kg/m3]
    % Higher Heating Value of Loaded HFO
    HHV_HFO = 43.0; %MJ/kg
    
    
% %%%%%%%%%%%% %%%%%%%%%%%% %%%%%%%%%%%%% %


% Checking correct total
LNG_met = Methane/100;
LNG_eta = Ethane/100;
LNG_pro = Propane/100;
LNG_isobut = isoButane/100;
LNG_nbut = nButane/100;
LNG_nit = Nitrogen/100;

xLNGisum = LNG_met + LNG_eta + LNG_pro + LNG_isobut + LNG_nbut + LNG_nit;

if round(xLNGisum*1000000) == 1000000;
    
    % %%%%%%%%%%%%% Parameters %%%%%%%%%%%%%% %
    
        %Mass Gross Calorific Value [MJ/kg]
        HHV_m = 55.5;
        HHV_e = 51.878;
        HHV_p = 50.350;
        HHV_ib = 49.5;
        HHV_nb = 49.5;
        HHV_n = 0;

        % Molar mass
        Mm = 0.016043; %kg/mol
        Me = 0.03007; % kg/mol
        Mp = 0.044097; % kg/mol
        Mib = 0.058123; % kg/mol
        Mnb = 0.058123; % kg/mol
        Mn = 0.02802; % kg/mol
        
        % Seconds per day:
        spd = 86400; %sec/day

     % %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% %   
        
            % Calculation of specific energy for the LNG %
            HHV_LNG = HHV_load(LNG_met, LNG_eta, LNG_pro, ...
                LNG_isobut, LNG_nbut, LNG_nit);
            
            % Calculation of FOE When Loading
            FOE_loading = FOE_claculation(HHV_HFO, HHV_LNG, Rho_LNG);
            
            % Calculating number of moles in LNG loaded included flashing
            Nlng_total = (Rho_LNG/(LNG_met*Mm + LNG_eta*Me + ...
                LNG_pro*Mp + LNG_isobut*Mib + LNG_nbut*Mnb + ...
                LNG_nit*Mn))*(V+((m_flash*t)/Rho_LNG));
            Nlng_nit = Nlng_total*LNG_nit;
            Nlng_met = Nlng_total*LNG_met;
            N_rest = Nlng_total - Nlng_nit - Nlng_met;
            
           
       
    Results = zeros([D,3]);
    VOL = zeros([D,1]);
    Percentage = zeros([D,5]);
    HeatingValue = zeros([D,2]);
    FOE_calc = zeros([D,2]);
    FUEL = zeros([D,3]);
    
    Heading1 = {'Day' 'xg_m' 'xg_n'  'xl_m' 'xl_n'};
    Heading2 = {'Nlng' 'Ngtot' 'Nltot'};
    Heading3 = { 'HHV_BOG [MJ/kg]' 'HHV_LNG [MJ/kg]'};
    Heading4 = { 'BOG_Volume' };
    Heading5 = { 'FOE_BOG' 'FOE_load'};
    Heading6 = { 'Fuel by BOG' 'Fuel by Load' 'Difference'};
    
    % %%%%%%%%%%%%% Flashing when loading %%%%%%%%%%%%% %

        flash = flash_load(LNG_nit, LNG_eta, m_flash, t, Rho_LNG);
        Nlng_total_flash = flash(1,1);
        Nlng_nit_flash = flash(2,1);
        Nlng_met_flash = flash(3,1);
        Volume_flash = flash(4,1);
        
    % %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% %    

    % %%%%% Amount after flashing when loading %%%%%%% %
   
        Nlng_tot = Nlng_total - Nlng_total_flash;
        Nlng_m = Nlng_met - Nlng_met_flash;
        Nlng_n = Nlng_nit - Nlng_nit_flash;        
        
        xLNG_nit = Nlng_n/Nlng_tot;
        xLNG_met = Nlng_m/Nlng_tot;

        
        %Only for testing
        x_rest = N_rest/Nlng_tot; 
        test = xLNG_nit + xLNG_met + x_rest;
        
    % %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% %

    % %%%%%%%%%% Amount BOG per interval %%%%%%%%%%%%% %
        Volume = V; %Afetr including new volume by flashing
        BOG_volume = Volume*BOR;
    
    % %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% %

    for i = int:int:D

        %Regression
        if LNG_eta <= 0.005
            a = -232.04;
            b = 21.937;
            c = 0;
        elseif LNG_eta <= 0.03
            a = -375.37;
            b = 27.521;
            c = 0;
        elseif LNG_eta <= 0.05
            a = -396.24;
            b = 28.511;
            c = 0;
        elseif LNG_eta <= 0.07
            a = -418.52;
            b = 29.541;
            c = 0;
        else
            a = -442.87;
            b = 30.622;
            c = 0;
        end
        
        % Mole [%] of BOG
        xgn = a*xLNG_nit^2 + b*xLNG_nit + c;
        xgm = 1 - xgn;
        
        %Calculation of BOG [Moles]
        BOG_total = (Rho_LNG/(xgm*Mm + xgn*Mn))*BOG_volume;    
        BOG_n = BOG_total*xgn;
        BOG_m = BOG_total*xgm;

            % For testing
%             vekt_n = BOG_n*Mn;
%             vekt_m = BOG_m*Mm;
%             volum_m = vekt_m/Rho_met;
%             volum_n = vekt_n/Rho_nit;
%             volumtotal = volum_n + volum_m
        
        % Amount liquid equal amount LNG minus BOG
            Nltot = Nlng_tot - BOG_total;

            Nlm = Nlng_m - BOG_m;
            Nln = Nlng_n - BOG_n;

            xlm = Nlm/(Nltot);
            xln = Nln/(Nltot);
        
        %Calculating HHV for BOG:
            % Mass weight
            Mass_met = Mm*xgm;
            Mass_nit = Mn*xgn;
            Total_mass = Mass_met + Mass_nit;
            % Mass fraction
            frac_met = Mass_met/Total_mass;
            frac_nit = Mass_nit/Total_mass;

            HHV_BOG = frac_met*HHV_m + frac_nit*HHV_n;
            
            FOE_BOG= FOE_claculation(HHV_HFO, HHV_BOG, Rho_LNG);
            FOE_calc(round(i/int),1) = FOE_BOG;
            FOE_calc(round(i/int),2) = FOE_loading;
            
            FUEL(round(i/int),1) = FOE_BOG*BOG_volume;
            FUEL(round(i/int),2) = FOE_loading*BOG_volume;
            FUEL(round(i/int),3) = FOE_loading*BOG_volume - FOE_BOG*BOG_volume;

% If constnat FOE:
%             FUEL(round(i/int),2) = 0.547*BOG_volume;
%             FUEL(round(i/int),3) = 0.547*BOG_volume - FOE_BOG*BOG_volume;

        VOL(round(i/int),1) = BOG_volume;
        Results(round(i/int),1) = Nlng_tot;
        Results(round(i/int),2) = BOG_total;
        Results(round(i/int),3) = Nltot;
        Percentage(round(i/int),1) = i;
        Percentage(round(i/int),2) = xgm;
        Percentage(round(i/int),3) = xgn;
        Percentage(round(i/int),4) = xlm;
        Percentage(round(i/int),5) = xln;
        HeatingValue(round(i/int),1) = HHV_BOG;
        HeatingValue(round(i/int),2) = HHV_LNG;
        FOE_calc(round(i/int),1) = FOE_BOG;
        FOE_calc(round(i/int),2) = FOE_loading;

        Nlng_tot = Nltot;
        Nlng_m = Nlm;
        Nlng_n = Nln;
                
        Volume_new = (Nlng_tot*(xlm*Mm + xln*Mn))/Rho_LNG;

        %Not included because of constant BOR
 %       BOG_volume = Volume_new*BOR;

        
        
        if Nlng_n >= 0
            xLNG_nit = Nlng_n/Nlng_tot; %Mole%
            xLNG_met = Nlng_m/Nlng_tot;
        else
            xLNG_nit = 0; %Mole%
            xLNG_met = Nlng_m/Nlng_tot;
        end

    end
    
    
    disp(Heading1)
    disp(Percentage)
    disp(Heading2)
    disp(Results)
    disp(Heading3)
    disp(HeatingValue)
    disp(Heading4)
    disp(VOL)
    disp(Heading5)
    disp(FOE_calc)
    disp(Heading6)
    disp(FUEL)

    X = Percentage(:,1); % Days of trial
    Y = HeatingValue(:,1); % HHV of BOG
    G = HeatingValue(:,2); %Heating Value LNG when loading
    Z = Percentage(:,2); %xgm
    T = Percentage(:,3); %xgn
    U = Percentage(:,4); %xlm
    V = Percentage(:,5); %xln
    F1 = FOE_calc(:,1); %FOE_BOG
    F2 = FOE_calc(:,2); %FOE_load
    Diff = FUEL(:,3);

    figure(1)
    plot(X,Z,X,T,'LineWidth',2)
    grid on
    title('Concentration of BOG', 'FontSize', 18, 'fontWeight','bold')
    xlabel('Days of trial [days]', 'FontSize', 14, 'fontWeight','bold')
    ylabel('Concentration [Fraction]', 'FontSize', 14, 'fontWeight','bold')
    legend('Methane','Nitrogen')
    axis([0 D+(D/2) -0.1 1.1])
    set(gca,'fontsize',14)

    figure(2)
    plot(X,Y,X,G,'LineWidth',2)
    grid on
    title('Changing in HHV During Voyage', 'FontSize', 18, 'fontWeight','bold')
    xlabel('Days of trial [days]', 'FontSize', 14, 'fontWeight','bold')
    ylabel('Lower Heating Value [MJ/kg]', 'FontSize', 14, 'fontWeight','bold')
    legend('Calculated HHV BOG','HHV LNG Loading')
    axis([0 D 30 65])
    set(gca,'fontsize',14)
    
    figure(3)
    plot(X,F1,X,F2,'LineWidth',2)
    grid on
    title('Changing in FOE During Voyage', 'FontSize', 18, 'fontWeight','bold')
    xlabel('Days of trial [days]', 'FontSize', 14, 'fontWeight','bold')
    ylabel('Fuel Oil Equivalent', 'FontSize', 14, 'fontWeight','bold')
    legend('FOE of BOG','FOE by Loading')
    axis([0 D 0.3 0.65])
    set(gca,'fontsize',14)

else 
        disp('konsentrasjonene stemmer ikke (ikke totalt 100%), rett opp og kjr igjen')
        disp('Total sum skal vaere 100, men er naa:')
        disp(xLNGisum*100)
end










